@@ -132,6 +132,8 @@
 #define isc_dpb_upgrade_db				  97
 #define isc_dpb_parallel_workers		 100
 #define isc_dpb_worker_attach			 101
+#define isc_dpb_max_blob_cache_size		 103
+#define isc_dpb_max_inline_blob_size	 104
 
 
 /**************************************************/
